@@ -30,8 +30,10 @@ static void sighandler(int sig) {
 
 void dumpdata(const unsigned int ticks, const char file[], const unsigned int limit) {
 
+#ifdef ENABLE_NLS
 	// This is a data format, so disable decimal point localization
 	setlocale(LC_NUMERIC, "C");
+#endif
 
 	// Set up signals to exit gracefully when terminated
 	struct sigaction sig;
@@ -113,6 +115,8 @@ void dumpdata(const unsigned int ticks, const char file[], const unsigned int li
 		fprintf(f, "db %.2f%%, ", db);
 		fprintf(f, "cb %.2f%%\n", cb);
 
+		fflush(f);
+
 		// Did we get a termination signal?
 		if (quit)
 			break;
